@@ -39,6 +39,7 @@ class PDE(PDEBase):
         bc: BoundariesData = "natural",
         bc_ops: "OrderedDict[str, BoundariesData]" = None,
         user_funcs: Dict[str, Any] = None,
+        consts: Dict[str, Any] = None,
     ):
         """
         Warning:
@@ -56,12 +57,14 @@ class PDE(PDEBase):
                 be specified with their full name, i.e., `laplace` for a scalar
                 Laplacian and `vector_laplace` for a Laplacian operating on a vector
                 field. Moreover, the dot product between two vector fields can be
-                denoted by using `dot(field1, field2)` in the expression.
+                denoted by using `dot(field1, field2)` in the expression, while an outer
+                product is calculated using `outer(field1, field2)`.
             noise (float or :class:`numpy.ndarray`):
                 Magnitude of additive Gaussian white noise. The default value of zero
                 implies deterministic partial differential equations will be solved.
                 Different noise magnitudes can be supplied for each field in coupled
-                PDEs.
+                PDEs by either specifying a sequence of numbers or a dictionary with
+                values for each field.
             bc:
                 Boundary conditions for the operators used in the expression. The
                 conditions here are applied to all operators that do not have a
@@ -72,12 +75,16 @@ class PDE(PDEBase):
                 dictionary specify where the boundary condition will be applied.
                 The keys follow the format "VARIABLE:OPERATOR", where VARIABLE specifies
                 the expression in `rhs` where the boundary condition is applied to the
-                operator specified by OPERATOR/. For both identifiers, the wildcard
+                operator specified by OPERATOR. For both identifiers, the wildcard
                 symbol "*" denotes that all fields and operators are affected,
                 respectively.
             user_funcs (dict, optional):
                 A dictionary with user defined functions that can be used in the
                 expressions in `rhs`.
+            consts (dict, optional):
+                A dictionary with user defined constants that can be used in the
+                expression. These can be either scalar numbers or fields defined on the
+                same grid as the actual simulation.
 
         Note:
             The order in which the fields are given in `rhs` defines the order in which
@@ -89,6 +96,12 @@ class PDE(PDEBase):
 
         from ..tools.expressions import ScalarExpression
 
+        # parse noise strength
+        if isinstance(noise, dict):
+            noise = [noise.get(var, 0) for var in rhs]
+        if hasattr(noise, "__iter__") and len(noise) != len(rhs):  # type: ignore
+            raise ValueError("Number of noise strengths does not match field count")
+
         super().__init__(noise=noise)
 
         # validate input
@@ -96,14 +109,16 @@ class PDE(PDEBase):
             rhs = OrderedDict(rhs)
         if "t" in rhs:
             raise RuntimeError("`t` is not allowed as a variable since it denotes time")
+        if consts is None:
+            consts = {}
 
         # turn the expression strings into sympy expressions
         self._rhs_expr, self._operators = {}, {}
         explicit_time_dependence = False
         complex_valued = False
         for var, rhs_str in rhs.items():
-            rhs_expr = ScalarExpression(rhs_str, user_funcs=user_funcs)
-            self._rhs_expr[var] = rhs_expr
+            consts_d = {name: None for name in consts}
+            rhs_expr = ScalarExpression(rhs_str, user_funcs=user_funcs, consts=consts_d)
 
             if rhs_expr.depends_on("t"):
                 explicit_time_dependence = True
@@ -117,9 +132,12 @@ class PDE(PDEBase):
                 if func.__class__.__name__ not in rhs_expr.user_funcs
             }
 
+            self._rhs_expr[var] = rhs_expr
+
         # set public instance attributes
         self.rhs = rhs
         self.variables = tuple(rhs.keys())
+        self.consts = consts
         self.explicit_time_dependence = explicit_time_dependence
         self.complex_valued = complex_valued
         operators = frozenset().union(*self._operators.values())  # type: ignore
@@ -156,6 +174,7 @@ class PDE(PDEBase):
         # save information for easy inspection
         self.diagnostics = {
             "variables": self.variables,
+            "constants": tuple(self.consts),
             "explicit_time_dependence": explicit_time_dependence,
             "complex_valued_rhs": complex_valued,
             "operators": operators,
@@ -201,15 +220,37 @@ class PDE(PDEBase):
         else:
             raise ValueError(f"Unknown state class {state.__class__.__name__}")
 
+        # check compatibility of constants and update the rhs accordingly
+        for name, value in self.consts.items():
+            # check whether the constant has a supported value
+            if np.isscalar(value):
+                pass  # this simple case is fine
+            elif isinstance(value, DataFieldBase):
+                value.grid.assert_grid_compatible(state.grid)
+                value = value.data  # just keep the actual discretized data
+            else:
+                raise TypeError(f"Constant has unsupported type {value.__class__}")
+
+            for rhs in self._rhs_expr.values():
+                rhs.consts[name] = value
+
         # obtain functions used in the expression
         ops_general = {}
 
-        # create a dot operator if necessary
+        # create special operators if necessary
         if "dot" in self.diagnostics["operators"]:  # type: ignore
             # add dot product between two vector fields. This can for instance
             # appear when two gradients of scalar fields need to be multiplied
             ops_general["dot"] = VectorField(state.grid).make_dot_operator()
 
+        if "inner" in self.diagnostics["operators"]:  # type: ignore
+            # synonym for dot product operator
+            ops_general["inner"] = VectorField(state.grid).make_dot_operator()
+
+        if "outer" in self.diagnostics["operators"]:  # type: ignore
+            # synonym for dot product operator
+            ops_general["outer"] = VectorField(state.grid).make_outer_prod_operator()
+
         # obtain the python functions for the rhs
         rhs_funcs = []
         for var in self.variables:
@@ -327,10 +368,12 @@ class PDE(PDEBase):
         cache = self._prepare_cache(state, backend="numpy")
 
         if isinstance(state, DataFieldBase):
+            # state is a single field
             rhs = cache["rhs_funcs"][0]
             return state.copy(data=rhs(state.data, t))
 
         elif isinstance(state, FieldCollection):
+            # state is a collection of fields
             result = state.copy()
             for i in range(len(state)):
                 data_tpl = cache["get_data_tuple"](state.data)
@@ -427,8 +470,12 @@ class PDE(PDEBase):
         cache = self._prepare_cache(state, backend="numba")
 
         if isinstance(state, DataFieldBase):
+            # state is a single field
             return jit(cache["rhs_funcs"][0])  # type: ignore
+
         elif isinstance(state, FieldCollection):
+            # state is a collection of fields
             return self._make_pde_rhs_numba_coll(state, cache)
+
         else:
             raise TypeError(f"Unsupported field {state.__class__.__name__}")
